@@ -1,7 +1,4 @@
 """
-Created by Joseph Edradan
-Github: https://github.com/josephedradan
-
 Date created: 6/25/2022
 
 Purpose:
@@ -22,6 +19,9 @@ Explanation:
 
 Tags:
 
+Contributors:
+    https://github.com/josephedradan
+
 Reference:
 
 """
